`timescale 1ns / 1ps
//////////////////////////////////////////////////////////////////////////////////
// Company:				Xilinx Inc.
// 
// Create Date:		09/02/2010 
// 
// Module Name:		My_XADC 
// Project Name: 		XADC UG Example
// Target Devices:	Virtex-7
// Tool versions:		13.0.2 Beta 2
// Description: 		Example XADC instantion monitoring on chip sensors and
//							auxillary analog input channels 0 - 3
// Dependencies: 
//
// Revision: 			1.0
// Comments:			See 7 series XADC User Guide 
//
//////////////////////////////////////////////////////////////////////////////////


module My_XADC
          (
			DADDR_IN,				// Address bus for the dynamic reconfiguration port
			DCLK_IN,					// Clock input for the dynamic reconfiguration port
			DEN_IN,					// Enable Signal for the dynamic reconfiguration port
			DI_IN,					// Input data bus for the dynamic reconfiguration port
			DWE_IN,					// Write Enable for the dynamic reconfiguration port
			RESET_IN,				// Reset signal for the System Monitor control logic
			VAUXP0,					// Auxiliary channel 0
			VAUXN0,
			VAUXP1,					// Auxiliary channel 1
			VAUXN1,
			VAUXP2,					// Auxiliary channel 2
			VAUXN2,
			VAUXP3,					// Auxiliary channel 3
			VAUXN3,
			BUSY_OUT,				// ADC Busy signal
			CHANNEL_OUT,			// Channel Selection Outputs
			DO_OUT,					// Output data bus for dynamic reconfiguration port
			DRDY_OUT,				// Data ready signal for the dynamic reconfiguration port
			EOC_OUT,					// End of Conversion Signal
			EOS_OUT,					// End of Sequence Signal
			OT_OUT,					// Over-Temperature alarm output
			VCCAUX_ALARM_OUT,		// VCCAUX-sensor alarm output
			VCCINT_ALARM_OUT,		// VCCINT-sensor alarm output
			USER_TEMP_ALARM_OUT,	// Temperature-sensor alarm output
			VBRAM_ALARM_OUT,		// VCCBRAM-sensor alarm output
			ALARM_OUT,				// OR'ed output of all the Alarms    
			VP_IN,					// Dedicated Analog Input Pair
			VN_IN);

			input [6:0] DADDR_IN;
			input DCLK_IN;
			input DEN_IN;
			input [15:0] DI_IN;
			input DWE_IN;
			input RESET_IN;
			input VAUXP0;
			input VAUXN0;
			input VAUXP1;
			input VAUXN1;
			input VAUXP2;
			input VAUXN2;
			input VAUXP3;
			input VAUXN3;
			input VP_IN;
			input VN_IN;

			output BUSY_OUT;
			output [4:0] CHANNEL_OUT;
			output [15:0] DO_OUT;
			output DRDY_OUT;
			output EOC_OUT;
			output EOS_OUT;
			output OT_OUT;
			output VCCAUX_ALARM_OUT;
			output VCCINT_ALARM_OUT;
			output USER_TEMP_ALARM_OUT;
			output VBRAM_ALARM_OUT;
			output ALARM_OUT;

			wire GND_BIT;
			assign GND_BIT = 0;
			wire [15:0] aux_channel_p;
			wire [15:0] aux_channel_n;
			wire [7:0] alm_int;
			
			assign ALARM_OUT = alm_int[7];
			assign VBRAM_ALARM_OUT = alm_int[3];
			assign VCCAUX_ALARM_OUT = alm_int[2];
			assign VCCINT_ALARM_OUT = alm_int[1];
			assign USER_TEMP_ALARM_OUT = alm_int[0];
			
			assign aux_channel_p[0] = VAUXP0;
			assign aux_channel_n[0] = VAUXN0;

			assign aux_channel_p[1] = VAUXP1;
			assign aux_channel_n[1] = VAUXN1;

			assign aux_channel_p[2] = VAUXP2;
			assign aux_channel_n[2] = VAUXN2;

			assign aux_channel_p[3] = VAUXP3;
			assign aux_channel_n[3] = VAUXN3;

			assign aux_channel_p[4] = 1'b0;
			assign aux_channel_n[4] = 1'b0;

			assign aux_channel_p[5] = 1'b0;
			assign aux_channel_n[5] = 1'b0;

			assign aux_channel_p[6] = 1'b0;
			assign aux_channel_n[6] = 1'b0;

			assign aux_channel_p[7] = 1'b0;
			assign aux_channel_n[7] = 1'b0;

			assign aux_channel_p[8] = 1'b0;
			assign aux_channel_n[8] = 1'b0;

			assign aux_channel_p[9] = 1'b0;
			assign aux_channel_n[9] = 1'b0;

			assign aux_channel_p[10] = 1'b0;
			assign aux_channel_n[10] = 1'b0;

			assign aux_channel_p[11] = 1'b0;
			assign aux_channel_n[11] = 1'b0;

			assign aux_channel_p[12] = 1'b0;
			assign aux_channel_n[12] = 1'b0;

			assign aux_channel_p[13] = 1'b0;
			assign aux_channel_n[13] = 1'b0;

			assign aux_channel_p[14] = 1'b0;
			assign aux_channel_n[14] = 1'b0;

			assign aux_channel_p[15] = 1'b0;
			assign aux_channel_n[15] = 1'b0;
			
XADC #(
										// Initialising the XADC Control Registers
			.INIT_40(16'h0000),	// config reg 0
			.INIT_41(16'h2ef0),	// Continuous Sequencer Mode, Disable unused ALMs, Enable calibration
			.INIT_42(16'h0400),	// Set DCLK divider to 4, ADC = 500Ksps, DCLK = 50MHz
			.INIT_48(16'h4701),	// Sequencer channel - enable on-chip sensors and calibration
			.INIT_49(16'h000f),	// Sequencer channel - enable aux channels 0 - 3
			.INIT_4A(16'h0000),	// Sequencer Average selection
			.INIT_4B(16'h0000),	// Sequencer Average selection
			.INIT_4C(16'h0000),	// Sequencer Bipolar selection
			.INIT_4D(16'h0000),	// Sequencer Bipolar selection
			.INIT_4E(16'h0000),	// Sequencer Acq time selection
			.INIT_4F(16'h0000),	// Sequencer Acq time selection
			.INIT_50(16'hb5ed),	// Temp upper alarm trigger 85C
			.INIT_51(16'h5999),	// Vccint upper alarm limit 1.05V
			.INIT_52(16'hA147),	// Vccaux upper alarm limit 1.89V
			.INIT_53(16'hdddd),	// OT upper alarm limit 125C
			.INIT_54(16'ha93a),	// Temp lower alarm reset 60C
			.INIT_55(16'h5111),	// Vccint lower alarm limit 0.95V
			.INIT_56(16'h91Eb),	// Vccaux lower alarm limit 1.71V
			.INIT_57(16'hae4e),	// OT lower alarm reset 70C
			.INIT_58(16'h5999),	// VBRAM upper alarm limit 1.05V
			.INIT_5C(16'h5111),	// VBRAM lower alarm limit 0.95V
			.SIM_MONITOR_FILE("sensor_input.txt")	// Analog Stimulous file
)

XADC_INST (							// See UG for port descriptions
			.CONVST(GND_BIT),		
			.CONVSTCLK(GND_BIT),
			.DADDR(DADDR_IN[6:0]),
			.DCLK(DCLK_IN),
			.DEN(DEN_IN),
			.DI(DI_IN[15:0]),
			.DWE(DWE_IN),
			.RESET(RESET_IN),
			.VAUXN(aux_channel_n[15:0]),
			.VAUXP(aux_channel_p[15:0]),
			.ALM(alm_int),
			.BUSY(BUSY_OUT),
			.CHANNEL(CHANNEL_OUT[4:0]),
			.DO(DO_OUT[15:0]),
			.DRDY(DRDY_OUT),
			.EOC(EOC_OUT),
			.EOS(EOS_OUT),
			.JTAGBUSY(),
			.JTAGLOCKED(),
			.JTAGMODIFIED(),
			.OT(OT_OUT),
			.MUXADDR(),
			.VP(VP_IN),
			.VN(VN_IN)
			);

endmodule
